@@ -1,14 +1,14 @@
 import os
 import socket
 import struct
-
+from typing import Optional
 from urllib.parse import unquote, urlparse
 
 """
 _url.py
 websocket - WebSocket client library for Python
 
-Copyright 2022 engn33r
+Copyright 2023 engn33r
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -26,7 +26,7 @@ limitations under the License.
 __all__ = ["parse_url", "get_proxy_info"]
 
 
-def parse_url(url):
+def parse_url(url: str) -> tuple:
     """
     parse url and the result is tuple of
     (hostname, port, resource path and the flag of secure mode)
@@ -67,7 +67,7 @@ def parse_url(url):
         resource = "/"
 
     if parsed.query:
-        resource += "?" + parsed.query
+        resource += f"?{parsed.query}"
 
     return hostname, port, resource, is_secure
 
@@ -75,7 +75,7 @@ def parse_url(url):
 DEFAULT_NO_PROXY_HOST = ["localhost", "127.0.0.1"]
 
 
-def _is_ip_address(addr):
+def _is_ip_address(addr: str) -> bool:
     try:
         socket.inet_aton(addr)
     except socket.error:
@@ -84,7 +84,7 @@ def _is_ip_address(addr):
         return True
 
 
-def _is_subnet_address(hostname):
+def _is_subnet_address(hostname: str) -> bool:
     try:
         addr, netmask = hostname.split("/")
         return _is_ip_address(addr) and 0 <= int(netmask) < 32
@@ -92,38 +92,51 @@ def _is_subnet_address(hostname):
         return False
 
 
-def _is_address_in_network(ip, net):
-    ipaddr = struct.unpack('!I', socket.inet_aton(ip))[0]
-    netaddr, netmask = net.split('/')
-    netaddr = struct.unpack('!I', socket.inet_aton(netaddr))[0]
+def _is_address_in_network(ip: str, net: str) -> bool:
+    ipaddr: int = struct.unpack("!I", socket.inet_aton(ip))[0]
+    netaddr, netmask = net.split("/")
+    netaddr: int = struct.unpack("!I", socket.inet_aton(netaddr))[0]
 
     netmask = (0xFFFFFFFF << (32 - int(netmask))) & 0xFFFFFFFF
     return ipaddr & netmask == netaddr
 
 
-def _is_no_proxy_host(hostname, no_proxy):
+def _is_no_proxy_host(hostname: str, no_proxy: Optional[list]) -> bool:
     if not no_proxy:
-        v = os.environ.get("no_proxy", os.environ.get("NO_PROXY", "")).replace(" ", "")
-        if v:
+        if v := os.environ.get("no_proxy", os.environ.get("NO_PROXY", "")).replace(
+            " ", ""
+        ):
             no_proxy = v.split(",")
     if not no_proxy:
         no_proxy = DEFAULT_NO_PROXY_HOST
 
-    if '*' in no_proxy:
+    if "*" in no_proxy:
         return True
     if hostname in no_proxy:
         return True
     if _is_ip_address(hostname):
-        return any([_is_address_in_network(hostname, subnet) for subnet in no_proxy if _is_subnet_address(subnet)])
-    for domain in [domain for domain in no_proxy if domain.startswith('.')]:
+        return any(
+            [
+                _is_address_in_network(hostname, subnet)
+                for subnet in no_proxy
+                if _is_subnet_address(subnet)
+            ]
+        )
+    for domain in [domain for domain in no_proxy if domain.startswith(".")]:
         if hostname.endswith(domain):
             return True
     return False
 
 
 def get_proxy_info(
-        hostname, is_secure, proxy_host=None, proxy_port=0, proxy_auth=None,
-        no_proxy=None, proxy_type='http'):
+    hostname: str,
+    is_secure: bool,
+    proxy_host: Optional[str] = None,
+    proxy_port: int = 0,
+    proxy_auth: Optional[tuple] = None,
+    no_proxy: Optional[list] = None,
+    proxy_type: str = "http",
+) -> tuple:
     """
     Try to retrieve proxy host and port from environment
     if not provided in options.
@@ -137,14 +150,14 @@ def get_proxy_info(
         Websocket server name.
     is_secure: bool
         Is the connection secure? (wss) looks for "https_proxy" in env
-        before falling back to "http_proxy"
+        instead of "http_proxy"
     proxy_host: str
         http proxy host name.
-    http_proxy_port: str or int
+    proxy_port: str or int
         http proxy port.
-    http_no_proxy: list
+    no_proxy: list
         Whitelisted host names that don't use the proxy.
-    http_proxy_auth: tuple
+    proxy_auth: tuple
         HTTP proxy auth information. Tuple of username and password. Default is None.
     proxy_type: str
         Specify the proxy protocol (http, socks4, socks4a, socks5, socks5h). Default is "http".
@@ -158,15 +171,17 @@ def get_proxy_info(
         auth = proxy_auth
         return proxy_host, port, auth
 
-    env_keys = ["http_proxy"]
-    if is_secure:
-        env_keys.insert(0, "https_proxy")
-
-    for key in env_keys:
-        value = os.environ.get(key, os.environ.get(key.upper(), "")).replace(" ", "")
-        if value:
-            proxy = urlparse(value)
-            auth = (unquote(proxy.username), unquote(proxy.password)) if proxy.username else None
-            return proxy.hostname, proxy.port, auth
+    env_key = "https_proxy" if is_secure else "http_proxy"
+    value = os.environ.get(env_key, os.environ.get(env_key.upper(), "")).replace(
+        " ", ""
+    )
+    if value:
+        proxy = urlparse(value)
+        auth = (
+            (unquote(proxy.username), unquote(proxy.password))
+            if proxy.username
+            else None
+        )
+        return proxy.hostname, proxy.port, auth
 
     return None, 0, None
